/*********************************************
* vim: set sw=8 ts=8 si :
* Author: Guido Socher, Copyright: GPL 
* Modified by: Nathanael Semhoun
* This program is to test the led connected to
* PC5 
* See http://linuxfocus.org/English/March2003/
* for details.
* Chip type           : AT90S4433
* Clock frequency     : 4,00 MHz
*********************************************/
#include <avr/io.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#include <string.h>
#include <stdlib.h>
#include "avr-util.h" 
#include "avr_compat.h"

void main(void)
{
	/* enable  PC5 as output */
	sbi(DDRC,PC5);
	/* PD7 input */
	sei(); /* enable interrupt */
	while (1) {
		/* blink led */
		cbi(PORTC,PC5);
		delay_ms(500);
		/* set output to 5V, LED off */
		sbi(PORTC,PC5);
		delay_ms(500);
	}
}

